/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#pragma once
#include <dawn/dawn.h>
#include "../../../ui/label.h"
#include "pokerplayerui.h"

/**
 * Initializes the UI Module.
 * 
 * @param pokerGame Poker game to initialize the UI for.
 */
void pokerUiInit(pokergame_t *pokerGame);

/**
 * Update the Poker Game UI.
 * 
 * @param pokerGame Game to update.
 * @param engine Engine to use for updating.
 */
void pokerUiUpdate(pokergame_t *pokerGame, engine_t *engine);

/**
 * Render the Poker Game UI.
 * 
 * @param pokerGame Game to render the UI for.
 * @param engine Engine to use for the render.
 */
void pokerUiRender(pokergame_t *pokerGame, engine_t *engine);

/**
 * Cleanup only the UI elements for a poker game.
 * 
 * @param pokerGame Game to dispose the UI for.
 */
void pokerUiDispose(pokergame_t *pokerGame);