/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "menulist.h"

void _menuListMenuOnSelect(menu_t *menu, menuitem_t *item, uint8_t i, void *u) {
  menulist_t *ml = (menulist_t *)u;
  if(ml->onSelect == NULL) return;
  ml->onSelect(ml, i, ml->user);
}

void menuListInit(menulist_t *ml, texture_t *texture) {
  ml->onSelect = NULL;

  // Initialize menu
  menuInit(&ml->menu);
  ml->menu.onSelect = &_menuListMenuOnSelect;
  ml->menu.user = (void *)ml;

  // Init the selection rectangle
  rectangleInit(&ml->selection);
  rectangleSetColor(&ml->selection, MENULIST_SELECTION_COLOR);

  // Init the frame
  frameInit(&ml->frame);
  ml->frame.texture = texture;
}

uint8_t menuListAdd(menulist_t *ml, font_t *font, char *text) {
  uint8_t i;
  label_t *label;
  menuitem_t *item;

  // Get the variables.
  i = ml->menu.itemCount;
  label = ml->labels + i;
  ml->items[i] = text;

  // Initialize the label.
  labelInit(label);
  labelSetText(label, font, text);

  // Reize the frame
  frameSetInnerSize(
    &ml->frame,
    100,
    FONT_LINE_HEIGHT * fontGetScale(label->fontSize) * (i+1)
  );

  // Add Menu Item
  item = menuAdd(&ml->menu);
  item->width = 1;
  item->height = 1;
  item->x = 0;
  item->y = i;
  
  return i;
}

void menuListUpdate(menulist_t *ml, engine_t *engine) {
  menuUpdate(&ml->menu, engine);
}

void menuListRender(menulist_t *ml, shader_t *shader, float x, float y) {
  uint8_t i;
  float fontScale;

  fontScale = fontGetScale(ml->labels->fontSize);

  // Render the frame
  frameRender(&ml->frame, shader, x, y);

  // Render selection box.
  ml->selection.width = 100;
  ml->selection.height = FONT_LINE_HEIGHT * fontScale;
  rectangleRender(&ml->selection, shader,
    x + FRAME_BORDER_SIZE,
    y + FRAME_BORDER_SIZE +ml->menu.selected * FONT_LINE_HEIGHT * fontScale
  );

  // Render each label.
  for(i = 0; i < ml->menu.itemCount; i++) {
    labelRender(ml->labels + i, shader,
      FRAME_BORDER_SIZE,
      FRAME_BORDER_SIZE + i * FONT_LINE_HEIGHT * fontScale
    );
  }
}

void menuListDispose(menulist_t *ml) {
  uint8_t i;
  for(i = 0; i < ml->menu.itemCount; i++) {
    labelDispose(ml->labels + i);
  }

  frameDispose(&ml->frame);
}