/**
 * Copyright (c) 2021 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "textmenu.h"

void _textMenuOnSelect(menuv2_t *menu, uint8_t i) {
  textmenu_t *textMenu = (textmenu_t *)menu->user;

  if(textMenu->onSelect != NULL) {
    textMenu->onSelect(textMenu->user, i, textMenu->texts[i]);
  }
}

void _textMenuOnResize(
  void *user, uint8_t i,
  float screenWidth, float screenHeight,
  float x, float y,
  float width, float height
) {
  textmenu_t *textMenu = (textmenu_t *)((menuv2_t *)user);
  label_t *label = textMenu->labels + i;
  textmenulabelinfo_t *info = textMenu->labelInfo + i;
  info->x = x;
  info->y = y;
  info->width = width;
  info->height = height;
  label->maxWidth = width;
  labelSetText(label, textMenu->font, textMenu->texts[i]);
}

void textMenuInit(textmenu_t *menu, font_t *font) {
  menu2Init(&menu->menu);
  rectangleInit(&menu->rectangle);
  rectangleSetColor(&menu->rectangle, MENULIST_SELECTION_COLOR);

  menu->menu.user = menu;
  menu->menu.onSelect = &_textMenuOnSelect;
  menu->font = font;
  menu->onSelect = NULL;
  menu->menu.grid.onResize = &_textMenuOnResize;
}

gridchild_t * textMenuListAdd(textmenu_t *menu, char *item) {
  menu->texts[menu->menu.grid.childCount] = item;
  labelInit(menu->labels + menu->menu.grid.childCount);
  (menu->labels + menu->menu.grid.childCount)->font = menu->font;
  return gridAddChild(&menu->menu.grid);
}

void textMenuListRender(textmenu_t *menu, shader_t *shader, float x, float y) {
  uint8_t i;
  label_t *label;
  textmenulabelinfo_t *info;
  
  info = menu->labelInfo + menu->menu.selected;
  menu->rectangle.width = info->width;
  menu->rectangle.height = info->height;
  rectangleRender(&menu->rectangle, shader, info->x, info->y);

  for(i = 0; i < menu->menu.grid.childCount; i++) {
    label = menu->labels + i;
    info = menu->labelInfo + i;
    labelRender(label, shader, x + info->x, y + info->y);
  }
}

void textMenuDispse(textmenu_t *menu) {
  uint8_t i;
  rectangleDispose(&menu->rectangle);
  for(i = 0; i < menu->menu.grid.childCount; i++) {
    labelDispose(menu->labels + i);
  }
}